Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(568)

Unified Diff: net/quic/chromium/quic_chromium_client_session.h

Issue 2337253004: Update Token Binding code to the latest drafts (Closed)
Patch Set: Fix compilation error in unit_tests Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/quic/chromium/quic_chromium_client_session.h
diff --git a/net/quic/chromium/quic_chromium_client_session.h b/net/quic/chromium/quic_chromium_client_session.h
index 6681592d45fe82096ed662ddc49a49e605ea111d..d1be70b28fdd700fd5921da76028ec313f9604f1 100644
--- a/net/quic/chromium/quic_chromium_client_session.h
+++ b/net/quic/chromium/quic_chromium_client_session.h
@@ -47,7 +47,8 @@ class SSLInfo;
class TransportSecurityState;
using TokenBindingSignatureMap =
- base::MRUCache<std::string, std::vector<uint8_t>>;
+ base::MRUCache<std::pair<TokenBindingType, std::string>,
+ std::vector<uint8_t>>;
namespace test {
class QuicChromiumClientSessionPeer;
@@ -195,9 +196,11 @@ class NET_EXPORT_PRIVATE QuicChromiumClientSession
// Gets the SSL connection information.
bool GetSSLInfo(SSLInfo* ssl_info) const;
// Signs the exported keying material used for Token Binding using key |*key|
// and puts the signature in |*out|. Returns a net error code.
Error GetTokenBindingSignature(crypto::ECPrivateKey* key,
+ TokenBindingType tb_type,
std::vector<uint8_t>* out);
// Performs a crypto handshake with the server.
@@ -195,9 +196,11 @@ class NET_EXPORT_PRIVATE QuicChromiumClientSession
// Gets the SSL connection information.
bool GetSSLInfo(SSLInfo* ssl_info) const;
- // Signs the exported keying material used for Token Binding using key |*key|
- // and puts the signature in |*out|. Returns a net error code.
+ // Generates the signature used in Token Binding using key |*key| and for a
+ // Token Binding of type |tb_type|, putting the signature in |*out|. Returns a
+ // net error code.
Error GetTokenBindingSignature(crypto::ECPrivateKey* key,

Powered by Google App Engine
This is Rietveld 408576698